> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #Fan Click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example
```
#include "fan_click.h"
#include "resources.h"
#include <stdbool.h>
#include <stdint.h>

sbit FAN_INT at GPIOD_IDR.B10;
sbit FAN_BTN at GPIOB_IDR.B0;

// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;
// End TFT module connections

// State of fan modes
enum
{
    MANUAL_STATE = 0,
    AUTOMATIC_STATE
} state;

// Prototypes
static void display_init( void );
static void system_init( void );
static long map( long x, long in_min, long in_max, long out_min,
                 long out_max );


// Implementations
static long map( long x, long in_min, long in_max, long out_min,
                 long out_max )
{
    return ( x - in_min ) * ( out_max - out_min ) / ( in_max - in_min ) + out_min;
}


static void display_init()
{
    TFT_Init_ILI9341_8bit( 320, 240 );
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Set_Brush( 1, CL_WHITE, 0, 0, 0, 0 );
    TFT_Set_Font( TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );

    TFT_Fill_Screen( CL_WHITE );
    TFT_Set_Pen( CL_Black, 1 );
    TFT_Line( 20, 220, 300, 220 );
    TFT_LIne( 20,  46, 300,  46 );
    TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "Fan click", 115, 14 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL );
    TFT_Write_Text( "EasyMx PRO v7 for STM32", 19, 223 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "www.mikroe.com", 200, 223 );
    TFT_Set_Font( &TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
    TFT_Write_Text( "RPM:", 110, 100 );
    TFT_Write_Text( "PWM:", 110, 115 );
    TFT_Write_Text( "%", 185, 115 );
}

static void system_init()
{
    ADC1_Init();
    GPIO_Digital_Input( &GPIOD_BASE, _GPIO_PINMASK_10 );
    GPIO_Digital_Input( &GPIOB_BASE, _GPIO_PINMASK_0 );

    I2C1_Init_Advanced( 400000, &_GPIO_MODULE_I2C1_PB67 );
    Delay_ms( 200 );
    fan_click_init( EMC2301_I2C_ADDR );
    fan_click_config_range( RPM_MIN_4000 );
    fan_click_config_enableFSC( false );
    fan_click_set_valid_tach( 12000 );
    fan_click_settings( 40.0f );
    display_init();
}

void main()
{
    char tmp_text[10];
    char tmp_floattxt[15];
    char rpmlbl[10] = { 0 };
    char pwmlbl[10] = { 0 };
    double fan_speed;
    uint16_t fan_rpm;
    int adc_new, adc_old = 0;
    bool auto_locked = false;

    system_init();

    while( 1 )
    {
        WordToStr( fan_click_get_tach(), tmp_text );
        FloatToStr( fan_click_get_settings(), tmp_floattxt );
        tmp_floattxt[4] = '\0';
        TFT_Set_Font( &TFT_defaultFont, CL_WHITE,
                      FO_HORIZONTAL ); // Color of background
        TFT_Write_Text( rpmlbl, 145, 100 );
        TFT_Write_Text( pwmlbl, 150, 115 );
        strcpy( rpmlbl, tmp_text );
        strcpy( pwmlbl, tmp_floattxt );
        TFT_Set_Font( &TFT_defaultFont, CL_BLACK, FO_HORIZONTAL ); // Color of text
        TFT_Write_Text( rpmlbl, 145, 100 );
        TFT_Write_Text( pwmlbl, 150, 115 );

        switch( state )
        {
            case MANUAL_STATE:
                adc_new = ADC1_Read( 3 );

                if( adc_new != adc_old )
                {
                    adc_old = adc_new;
                    fan_speed = map( adc_new, 0, 4096, 0, 100 );
                    fan_click_settings( fan_speed );
                    TFT_Set_Font( &TFT_defaultFont, CL_BLACK, FO_HORIZONTAL ); // Color of text
                    TFT_Write_Text( "Manual", 20, 50 );
                }
                break;
            case AUTOMATIC_STATE:
                if( !auto_locked )
                {
                    fan_rpm = fan_click_get_tach();
                    fan_click_set_min_drive( 40.0f );
                    fan_click_config_enableFSC( true );
                    fan_click_set_target_tach( fan_rpm );
                    auto_locked = true;
                    TFT_Set_Font( &TFT_defaultFont, CL_BLACK, FO_HORIZONTAL ); // Color of text
                    TFT_Write_Text( "Automatic", 20, 50 );
                }
                break;
        }

        if( Button( &GPIOB_IDR, 0, 80, 0 ) )
        {
            // Clear dynamic areas on the screen
            TFT_Set_Pen( CL_WHITE, 2 );
            TFT_Set_Brush( 1, CL_WHITE, 0, LEFT_TO_RIGHT, CL_BLACK, CL_WHITE );
            TFT_Rectangle( 18, 50, 90, 110 );
            state = !state;
            auto_locked = false;
            fan_click_config_enableFSC( false );
        }

        Delay_ms( 100 );
    }
}
```
